Project Information
===================

**Lightshow** is licensed under the BSD 3-clause "revised" license and was developed as part of the `Integrated Platform for Multimodal Data Capture, Exploration and Discovery Driven by AI Tools` (AIMM) project.

.. toctree::

   project/authors.rst
   project/funding.rst
   project/license.rst
